@@ -57,12 +57,20 @@ typedef int (av1_packet_h)(bool marker, uint64_t rtp_ts,
 			    const uint8_t *pld, size_t pld_len,
 			    void *arg);
 
-int av1_packetize_high(bool *newp, bool marker, uint64_t rtp_ts,
-		       const uint8_t *buf, size_t len, size_t maxlen,
-		       av1_packet_h *pkth, void *arg);
-int av1_packetize_one_w(bool *newp, bool marker, uint64_t rtp_ts,
-			const uint8_t *buf, size_t len, size_t maxlen,
-			av1_packet_h *pkth, void *arg);
+int av1_packetize(bool *newp, bool marker, uint64_t rtp_ts,
+		  const uint8_t *buf, size_t len, size_t maxlen,
+		  av1_packet_h *pkth, void *arg);
+
+
+/* XXX: wrapper for backwards compat -- remove later */
+static inline int av1_packetize_new(bool *newp, bool marker, uint64_t rtp_ts,
+				    const uint8_t *buf, size_t len,
+				    size_t maxlen,
+				    av1_packet_h *pkth, void *arg)
+{
+	return av1_packetize(newp, marker, rtp_ts, buf, len,
+			     maxlen, pkth, arg);
+}
 
 
 enum {
